asr.test.test\_setup\_displacements
===================================

.. automodule:: asr.test.test_setup_displacements

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_setup_displacements
   .. autofunction:: test_setup_displacements_displace_atom
   .. autofunction:: test_setup_displacements_get_all_displacements
   
   

   
   
   

   
   
   